@@ -15,11 +15,12 @@ Non-stable APIs they should be placed in the `helpers.py` module instead.
    - New parameters should have safe defaults
  * For breaking changes, new functions should be created
 """
+import crum
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.sites.models import Site
 from organizations import api as organizations_api
-from organizations.models import Organization
+from organizations.models import Organization, OrganizationCourse
 
 from tahoe_sites import zd_helpers
 from tahoe_sites.models import TahoeSite, UserOrganizationMapping
@@ -60,7 +61,7 @@ def get_organization_for_user(user, fail_if_inactive=True, fail_if_site_admin=Fa
     :return: Organization objects related to the given user
     """
     if fail_if_inactive:
-        extra_params = {'is_active': True}
+        extra_params = {'user__is_active': True}
     else:
         extra_params = {}
     if fail_if_site_admin:
@@ -82,7 +83,7 @@ def get_users_of_organization(organization, without_inactive_users=True, without
     :return: User objects related to the given organization
     """
     if without_inactive_users:
-        extra_params = {'is_active': True}
+        extra_params = {'user__is_active': True}
     else:
         extra_params = {}
     if without_site_admins:
@@ -92,22 +93,6 @@ def get_users_of_organization(organization, without_inactive_users=True, without
     )
 
 
-def is_active_admin_on_any_organization(user, org_ids):
-    """
-    Check if the given user is an admin on any of the given organizations
-
-    :param user: user to filter on
-    :param org_ids: QuerySet of organization ids to filter on
-    :return: <True> if user is an admin on any organization, <False> otherwise
-    """
-    return UserOrganizationMapping.objects.filter(
-        user=user,
-        organization_id__in=org_ids,
-        is_active=True,
-        is_admin=True,
-    ).exists()
-
-
 def is_active_admin_on_organization(user, organization):
     """
     Check if the given user is an admin on the given organizations
@@ -119,8 +104,8 @@ def is_active_admin_on_organization(user, organization):
     return UserOrganizationMapping.objects.filter(
         user=user,
         organization=organization,
-        is_active=True,
         is_admin=True,
+        user__is_active=True,
     ).exists()
 
 
@@ -266,18 +251,25 @@ def get_uuid_by_site(site):
     return TahoeSite.objects.get(site=site).site_uuid
 
 
-def get_current_site(request):
+def get_site_by_request(request):
     """
-    Return current site.
+    Return the current site from the given request
 
-    This is a copy of Open edX's `openedx.core.djangoapps.theming.helpers.get_current_site`.
-
-    Returns:
-         (django.contrib.sites.models.Site): returns current site
+    :param request: request to get the site from
+    :return: site value in the request
     """
     return getattr(request, 'site', None)
 
 
+def get_current_site():
+    """
+    Return the current site using crum
+
+    :return: site value in the request
+    """
+    return get_site_by_request(request=crum.get_current_request())
+
+
 def get_current_organization(request):
     """
     Return a single organization for the current site.
@@ -288,10 +280,36 @@ def get_current_organization(request):
     :raise Organization.MultipleObjectsReturned when more than one organization is returned.
     :return Organization.
     """
-    current_site = get_current_site(request)
+    current_site = get_site_by_request(request)
 
-    main_site_id = getattr(settings, 'SITE_ID', None)
-    if main_site_id and current_site and current_site.id == main_site_id:
+    if is_main_site(get_site_by_request(request)):
         raise Organization.DoesNotExist('Tahoe Sites: Should not find organization of main site `settings.SITE_ID`')
 
     return get_organization_by_site(current_site)
+
+
+def is_main_site(site):
+    """
+    Returns True if the given site is the default one. Returns False otherwise
+
+    :param site: site to check
+    :return: boolean, check result
+    """
+    main_site_id = getattr(settings, 'SITE_ID', None)
+    return main_site_id and site and site.id == main_site_id
+
+
+def get_organization_by_course(course_id):
+    """
+    Get the organization related to the given course. This method raises an error if the course is linked to
+    many organizations
+
+    :param course_id: course to get the organization for it
+    :return: the related organization
+    """
+    return Organization.objects.filter(
+        pk__in=OrganizationCourse.objects.filter(
+            course_id=str(course_id),
+            active=True,
+        ).values_list('organization_id', flat=True)
+    ).get()
