@@ -1,5 +1,5 @@
 """
-Tests for models
+Tests for APIs
 """
 # pylint: disable=too-many-public-methods
 
@@ -10,7 +10,8 @@ import ddt
 import pytest
 from django.conf import settings
 from django.contrib.sites.models import Site
-from organizations.models import Organization
+from django.core.exceptions import MultipleObjectsReturned
+from organizations.models import Organization, OrganizationCourse
 
 from tahoe_sites import api
 from tahoe_sites.models import TahoeSite, UserOrganizationMapping
@@ -97,8 +98,8 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         assert api.get_organization_for_user(self.org2_first_user) == self.org2
 
         # records with inactive user will not be returned
-        self.mapping.is_active = False
-        self.mapping.save()
+        self.org2_first_user.is_active = False
+        self.org2_first_user.save()
         with self.assertRaises(expected_exception=Organization.DoesNotExist):
             api.get_organization_for_user(self.org2_first_user)
 
@@ -109,8 +110,8 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         """
         self._prepare_mapping_data()
 
-        self.mapping.is_active = False
-        self.mapping.save()
+        self.default_user.is_active = False
+        self.default_user.save()
         assert api.get_organization_for_user(self.default_user, fail_if_inactive=False) == self.default_org
 
     def test_get_organization_for_user_without_admins(self):
@@ -138,8 +139,8 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         assert list(api.get_users_of_organization(self.org2)) == [self.org2_first_user, self.org2_second_user]
 
         # inactive users will not be returned
-        self.mapping.is_active = False
-        self.mapping.save()
+        self.org2_first_user.is_active = False
+        self.org2_first_user.save()
         assert list(api.get_users_of_organization(self.org2)) == [self.org2_second_user]
 
     def test_get_users_of_organization_with_inactive_users(self):
@@ -149,8 +150,8 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         """
         self._prepare_mapping_data()
 
-        self.mapping.is_active = False
-        self.mapping.save()
+        self.org2_first_user.is_active = False
+        self.org2_first_user.save()
         assert list(api.get_users_of_organization(self.org2, without_inactive_users=False)) == [
             self.org2_first_user,
             self.org2_second_user
@@ -306,19 +307,46 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         """
         assert api.get_uuid_by_site(site=self.default_django_site) == api.get_uuid_by_organization(self.default_org)
 
-    def test_get_current_site_no_site(self):
+    def test_get_current_site_use_crum(self):
         """
-        Emulate the behaviour of `openedx.core.djangoapps.theming.helpers.get_current_site`.
+        Verify that get_current_site will use crum to get current request
+        """
+        with mock.patch(
+            'tahoe_sites.api.crum.get_current_request',
+            return_value=mock.Mock(site={'domain': 'test.org'})
+        ) as mocked_current_request:
+            self.assertEqual(api.get_current_site(), {'domain': 'test.org'})
+
+        mocked_current_request.assert_called_with()
+
+    def test_get_current_site_no_request_found(self):
+        """
+        Verify that get_current_site will return None if crum.get_current_request returns None for any reason!
+        """
+        with mock.patch('tahoe_sites.api.crum.get_current_request', return_value=None) as mocked_current_request:
+            self.assertIsNone(api.get_current_site())
+
+        mocked_current_request.assert_called_with()
+
+    def test_get_site_by_request_none_request(self):
+        """
+        Verify that get_site_by_request will return None when the given request is None
+        """
+        self.assertIsNone(api.get_site_by_request(request=None))
+
+    def test_get_site_by_request_no_site(self):
+        """
+        Verify that get_site_by_request will return None when no site found in the request
         """
         request = mock.Mock(site=None)
-        self.assertFalse(api.get_current_site(request))
+        self.assertIsNone(api.get_site_by_request(request))
 
-    def test_get_current_site_with_site(self):
+    def test_get_site_by_request_with_site(self):
         """
-        Emulate the behaviour of `openedx.core.djangoapps.theming.helpers.get_current_site`.
+        Verify that get_site_by_request will return the site in the request
         """
         request = mock.Mock(site={'domain': 'test.org'})
-        self.assertTrue(api.get_current_site(request))
+        self.assertIsNotNone(api.get_site_by_request(request))
 
     def test_update_admin_role_active_mapping(self):
         """
@@ -349,12 +377,11 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         Test update_admin_role_in_organization on inactive UserOrganizationMapping.
         """
         self._prepare_mapping_data()
-        mapping = self.mapping
-        mapping.is_active = False
-        mapping.save()
 
-        user = mapping.user
-        organization = mapping.organization
+        user = self.mapping.user
+        user.is_active = False
+        user.save()
+        organization = self.mapping.organization
 
         # Set as admin, but for inactive.
         api.update_admin_role_in_organization(user, organization, set_as_admin=True)
@@ -407,3 +434,89 @@ class TestAPIHelpers(DefaultsForTestsMixin):
         assert mapping.user == self.default_user
         assert mapping.organization == self.default_org
         assert mapping.is_admin == is_admin
+
+    @ddt.data(
+        (settings.SITE_ID, True),
+        (settings.SITE_ID + 1, False),
+        (None, False),
+    )
+    @ddt.unpack
+    def test_is_main_site(self, site_id, expected_result):
+        """
+        Verify that is_main_site works correctly
+        """
+        self.assertEqual(api.is_main_site(site=mock.Mock(id=site_id)), expected_result)
+
+    def test_is_main_site_none(self):
+        """
+        Verify that is_main_site returns False if the given site is None
+        """
+        self.assertFalse(api.is_main_site(site=None))
+
+    def test_is_main_site_settings_is_none(self):
+        """
+        Verify that is_main_site returns False if settings.SITE_ID is None
+        """
+        with mock.patch.object(settings, 'SITE_ID', None):
+            self.assertFalse(api.is_main_site(site=mock.Mock(id=99)))
+
+    @staticmethod
+    def add_organization_course(organization, course_id='dummy_key', active=True):
+        """
+        Helper to create an OrganizationCourse object
+        """
+        return OrganizationCourse.objects.create(
+            course_id=course_id,
+            organization=organization,
+            active=active,
+        )
+
+    def test_get_organization_by_course(self):
+        """
+        Verify that get_organization_by_course returns the related organization of the given course
+        """
+        self.add_organization_course(organization=self.default_org)
+
+        assert api.get_organization_by_course(course_id='dummy_key') == self.default_org
+
+    def test_get_organization_by_course_inactive_link(self):
+        """
+        Verify that get_organization_by_course raises an exception if the course link is inactive
+        """
+        self.add_organization_course(organization=self.default_org, active=False)
+
+        with self.assertRaises(expected_exception=Organization.DoesNotExist):
+            api.get_organization_by_course(course_id='dummy_key')
+
+    def test_get_organization_by_course_bad_course(self):
+        """
+        Verify that get_organization_by_course raises an exception if the course is not related to any organization
+        (or maybe the course doesn't exist)
+        """
+        with self.assertRaises(expected_exception=Organization.DoesNotExist):
+            api.get_organization_by_course(course_id='dummy_key')
+
+    def test_get_organization_by_course_multi_organization(self):
+        """
+        Verify that get_organization_by_course raises an exception if the course is related to many organizations
+        """
+        second_org = self.create_organization(name='second_org', short_name='O2')
+        self.add_organization_course(organization=self.default_org)
+        self.add_organization_course(organization=second_org)
+
+        with self.assertRaises(expected_exception=MultipleObjectsReturned):
+            api.get_organization_by_course(course_id='dummy_key')
+
+    def test_get_organization_by_course_only_one_active(self):
+        """
+        Verify that get_organization_by_course allows having multiple organization-course links if only one of them
+        is active
+        """
+        second_org = self.create_organization(name='second_org', short_name='O2')
+        third_org = self.create_organization(name='third_org', short_name='O3')
+
+        self.add_organization_course(organization=second_org, active=False)
+        self.add_organization_course(organization=third_org, active=False)
+        self.add_organization_course(organization=self.default_org)
+
+        assert api.get_organization_by_course(course_id='dummy_key') == self.default_org
